==> ginkgocadx_2.6.0.0~rc.orig.tar.gz: ginkgocadx-2.6.0.0/src/lightvisualizator/lightvisualizator/controllers/lightvisualizatorcontroller.h <==
/*
 *  $Id: lightvisualizatorcontroller.h 3913 2011-07-04 11:45:56Z tovar $
 *  Proyecto Ginkgo
 *
 *  Copyright 2008 MetaEmotion S.L. All rights reserved.
 *
 */
#pragma once

#include <api/icontroladormodulo.h>

namespace LightVisualizator {

	//Defines extension capabilities and is the entry point for extension workflows
	class LightVisualizatorController : public GNC::GCS::IControladorModulo {
	public:

		/* Constructor */
		LightVisualizatorController(GNC::GCS::IEntorno* pEntorno);

		/* Destructor */
		virtual ~LightVisualizatorController();

		//It's mandatory to implement this method, here you have to register views of this module, this will register LightVisualizatorView.
		virtual void RegistrarVistas();

		//it's call by Ginkgo CADx core when this extension has to open a series with required module and required Diagnostic Study UID
		virtual GNC::GCS::IVista* AbrirVista(int modo, ListaDescriptoresSerie& series, const std::string& uidEstudioDiagnostico = "");

		//it supports importation workflow?
		virtual bool SoportaImportacion() const;


		//return importation steps, importation workflow is structured as a wizard proccess, each step implements IPasoWizard interface, typical importation
		//process starts with image selection step, all steps has image path list (m_pListaFicheros)
		virtual void GetPasosImportacion(IWizard* pWizard,std::list<IPasoWizard*> &listaPasos, wxWindow* pParent, std::string &dirTemporal,GnkPtr<GIL::IModeloIntegracion> pModeloIntegracion);

	protected:
		
	};

}

==> ginkgocadx_2.12.0.4889.orig.tar.gz: ginkgocadx-2.12.0.4889/src/lightvisualizator/lightvisualizator/controllers/lightvisualizatorcontroller.h <==
/*
 *  $Id: lightvisualizatorcontroller.h 4615 2012-01-26 14:00:07Z tovar $
 *  Proyecto Ginkgo
 *
 *  Copyright 2008 MetaEmotion S.L. All rights reserved.
 *
 */
#pragma once

#include <api/icontroladormodulo.h>

namespace LightVisualizator {

	//Defines extension capabilities and is the entry point for extension workflows
	class LightVisualizatorController : public GNC::GCS::IControladorModulo {
	public:

		/* Constructor */
		LightVisualizatorController(GNC::GCS::IEntorno* pEntorno);

		/* Destructor */
		virtual ~LightVisualizatorController();

		//It's mandatory to implement this method, here you have to register views of this module, this will register LightVisualizatorView.
		virtual void RegistrarVistas();

		//it's call by Ginkgo CADx core when this extension has to open a series with required module and required Diagnostic Study UID
		virtual GNC::GCS::IVista* AbrirVista(int modo, ListaDescriptoresSerie& series, const std::string& uidEstudioDiagnostico = "");

		//it supports importation workflow?
		virtual bool SoportaImportacion() const;


		//return importation steps, importation workflow is structured as a wizard Process, each step implements IPasoWizard interface, typical importation
		//process starts with image selection step, all steps has image path list (m_pListaFicheros)
		virtual void GetPasosImportacion(IWizard* pWizard,std::list<IPasoWizard*> &listaPasos, wxWindow* pParent, std::string &dirTemporal,GnkPtr<GIL::IModeloIntegracion> pModeloIntegracion);

	protected:
		
	};

}
